"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.prepare = prepare;
exports.prepareSync = prepareSync;
exports.path = path;
exports.get = get;
exports.getSync = getSync;
exports.save = save;
exports.saveSettings = saveSettings;

var _uuid = require("uuid");

var utils = _interopRequireWildcard(require("./utils"));

var crypto = _interopRequireWildcard(require("./crypto"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const EMPTY_CONFIG = {
  servers: []
};

function sanitizeServer(server, cryptoSecret) {
  const srv = _objectSpread({}, server); // ensure has an unique id


  if (!srv.id) {
    srv.id = (0, _uuid.v4)();
  } // ensure has the new fileld SSL


  srv.ssl = srv.ssl || false; // ensure all secret fields are encrypted

  if (typeof srv.encrypted === 'undefined') {
    srv.encrypted = true;

    if (srv.password) {
      srv.password = crypto.encrypt(srv.password, cryptoSecret);
    }

    if (srv.ssh && srv.ssh.password) {
      srv.ssh.password = crypto.encrypt(srv.ssh.password, cryptoSecret);
    }
  } else if (srv.encrypted) {
    if (srv.password && typeof srv.password === 'string') {
      srv.password = crypto.encrypt(crypto.unsafeDecrypt(srv.password, cryptoSecret), cryptoSecret);
    }

    if (srv.ssh && srv.ssh.password && typeof srv.ssh.password === 'string') {
      srv.ssh.password = crypto.encrypt(crypto.unsafeDecrypt(srv.ssh.password, cryptoSecret), cryptoSecret);
    }
  }

  return srv;
}

function sanitizeServers(data, cryptoSecret) {
  return data.servers.map(server => sanitizeServer(server, cryptoSecret));
}
/**
 * Prepare the configuration file sanitizing and validating all fields availbale
 */


function prepare(_x) {
  return _prepare.apply(this, arguments);
}

function _prepare() {
  _prepare = _asyncToGenerator(function* (cryptoSecret) {
    const filename = utils.getConfigPath();
    const fileExistsResult = yield utils.fileExists(filename);

    if (!fileExistsResult) {
      yield utils.createParentDirectory(filename);
      yield utils.writeJSONFile(filename, EMPTY_CONFIG);
    }

    const result = yield utils.readJSONFile(filename);
    result.servers = sanitizeServers(result, cryptoSecret);
    yield utils.writeJSONFile(filename, result); // TODO: Validate whole configuration file
    // if (!configValidate(result)) {
    //   throw new Error('Invalid ~/.sqlectron.json file format');
    // }
  });
  return _prepare.apply(this, arguments);
}

function prepareSync(cryptoSecret) {
  const filename = utils.getConfigPath();
  const fileExistsResult = utils.fileExistsSync(filename);

  if (!fileExistsResult) {
    utils.createParentDirectorySync(filename);
    utils.writeJSONFileSync(filename, EMPTY_CONFIG);
  }

  const result = utils.readJSONFileSync(filename);
  result.servers = sanitizeServers(result, cryptoSecret);
  utils.writeJSONFileSync(filename, result); // TODO: Validate whole configuration file
  // if (!configValidate(result)) {
  //   throw new Error('Invalid ~/.sqlectron.json file format');
  // }
}

function path() {
  const filename = utils.getConfigPath();
  return utils.resolveHomePathToAbsolute(filename);
}

function get() {
  const filename = utils.getConfigPath();
  return utils.readJSONFile(filename);
}

function getSync() {
  const filename = utils.getConfigPath();
  return utils.readJSONFileSync(filename);
}

function save(data) {
  const filename = utils.getConfigPath();
  return utils.writeJSONFile(filename, data);
}

function saveSettings(_x2) {
  return _saveSettings.apply(this, arguments);
}

function _saveSettings() {
  _saveSettings = _asyncToGenerator(function* (data) {
    const fullData = yield get();
    const filename = utils.getConfigPath();

    const newData = _objectSpread(_objectSpread({}, fullData), data);

    return utils.writeJSONFile(filename, newData);
  });
  return _saveSettings.apply(this, arguments);
}