"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getConfigPath = getConfigPath;
exports.fileExists = fileExists;
exports.fileExistsSync = fileExistsSync;
exports.writeFile = writeFile;
exports.writeJSONFile = writeJSONFile;
exports.writeJSONFileSync = writeJSONFileSync;
exports.readJSONFile = readJSONFile;
exports.readJSONFileSync = readJSONFileSync;
exports.createParentDirectory = createParentDirectory;
exports.createParentDirectorySync = createParentDirectorySync;
Object.defineProperty(exports, "createCancelablePromise", {
  enumerable: true,
  get: function () {
    return _utils.createCancelablePromise;
  }
});
Object.defineProperty(exports, "getPort", {
  enumerable: true,
  get: function () {
    return _utils.getPort;
  }
});
Object.defineProperty(exports, "readFile", {
  enumerable: true,
  get: function () {
    return _utils.readFile;
  }
});
Object.defineProperty(exports, "resolveHomePathToAbsolute", {
  enumerable: true,
  get: function () {
    return _utils.resolveHomePathToAbsolute;
  }
});
Object.defineProperty(exports, "versionCompare", {
  enumerable: true,
  get: function () {
    return _utils.versionCompare;
  }
});

var _fs = _interopRequireDefault(require("fs"));

var _os = require("os");

var _path = _interopRequireDefault(require("path"));

var _mkdirp = _interopRequireDefault(require("mkdirp"));

var _envPaths = _interopRequireDefault(require("env-paths"));

var _utils = require("sqlectron-db-core/utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let configPath = '';

function getConfigPath() {
  if (configPath) {
    return configPath;
  }

  const configName = 'sqlectron.json';

  const oldConfigPath = _path.default.join((0, _os.homedir)(), `.${configName}`);

  if (process.env.SQLECTRON_HOME) {
    configPath = _path.default.join(process.env.SQLECTRON_HOME, configName);
  } else if (fileExistsSync(oldConfigPath)) {
    configPath = oldConfigPath;
  } else {
    const newConfigDir = (0, _envPaths.default)('Sqlectron', {
      suffix: ''
    }).config;
    configPath = _path.default.join(newConfigDir, configName);
  }

  return configPath;
}

function fileExists(filename) {
  return new Promise(resolve => {
    _fs.default.stat(filename, (err, stats) => {
      if (err) return resolve(false);
      resolve(stats.isFile());
    });
  });
}

function fileExistsSync(filename) {
  try {
    return _fs.default.statSync(filename).isFile();
  } catch (e) {
    return false;
  }
}

function writeFile(filename, data) {
  return new Promise((resolve, reject) => {
    _fs.default.writeFile(filename, data, err => {
      if (err) return reject(err);
      resolve();
    });
  });
}

function writeJSONFile(filename, data) {
  return writeFile(filename, JSON.stringify(data, null, 2));
}

function writeJSONFileSync(filename, data) {
  return _fs.default.writeFileSync(filename, JSON.stringify(data, null, 2));
}

function readJSONFile(filename) {
  return (0, _utils.readFile)(filename).then(data => JSON.parse(data));
}

function readJSONFileSync(filename) {
  const filePath = (0, _utils.resolveHomePathToAbsolute)(filename);

  const data = _fs.default.readFileSync(_path.default.resolve(filePath), {
    enconding: 'utf-8'
  });

  return JSON.parse(data);
}

function createParentDirectory(filename) {
  return (0, _mkdirp.default)(_path.default.dirname(filename));
}

function createParentDirectorySync(filename) {
  _mkdirp.default.sync(_path.default.dirname(filename));
}